@@ -72,9 +72,11 @@ assert_input_categorical <- function(
     assert_matrix(predicted, nrows = n)
     summed_predictions <- round(rowSums(predicted, na.rm = TRUE), 10) # avoid numeric errors
   }
-  if (!all(summed_predictions == 1)) {
+  # Allow for numeric errors
+  invalid_rows <- abs(summed_predictions - 1) > 1e-4
+  if (any(invalid_rows)) {
     #nolint start: keyword_quote_linter object_usage_linter
-    row_indices <- as.character(which(summed_predictions != 1))
+    row_indices <- which(invalid_rows)
     cli_abort(
       c(
         `!` = "Probabilities belonging to a single forecast must sum to one",
