@@ -545,3 +545,31 @@ test_that("plot_pairwise_comparisons() works when showing p values", {
   skip_on_cran()
   vdiffr::expect_doppelganger("plot_pairwise_comparison_pval", p)
 })
+
+test_that("add_relative_skill() works without warnings when not computing p-values", {
+  forecast_quantile <- example_quantile %>%
+    as_forecast_quantile(
+      forecast_unit = c(
+        "location", "forecast_date", "target_end_date",
+        "target_type", "model", "horizon"
+      )
+    )
+
+  scores <- forecast_quantile %>%
+    score(metrics = get_metrics(forecast_quantile, "ae_median"))
+
+  expect_no_warning(
+    scores_w_rel_skill <- scores %>%
+      add_relative_skill(
+        compare = "model",
+        by = "location",
+        metric = "ae_median",
+        test_type = NULL
+      )
+  )
+
+  # Additional checks to ensure the function worked correctly
+  expect_true("ae_median_relative_skill" %in% names(scores_w_rel_skill))
+  expect_true(is.numeric(scores_w_rel_skill$ae_median_relative_skill))
+  expect_false(any(is.na(scores_w_rel_skill$ae_median_relative_skill)))
+})
